@@ -28,11 +28,11 @@
 #include <tqwhatsthis.h>
 
 #include <kcombobox.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 #include <kiconloader.h>
 #include <kinputdialog.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kuser.h>
 
 
@@ -64,7 +64,7 @@ namespace Konversation
         connect(newBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(newIdentity()));
 
         TQToolButton* copyBtn = new TQToolButton(mainWidget);
-        copyBtn->setIconSet(SmallIconSet("editcopy"));
+        copyBtn->setIconSet(SmallIconSet("edit-copy"));
         copyBtn->setTextLabel(i18n("Duplicate"));
         connect(copyBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(copyIdentity()));
 
@@ -74,7 +74,7 @@ namespace Konversation
         connect(m_editBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(renameIdentity()));
 
         m_delBtn = new TQToolButton(mainWidget);
-        m_delBtn->setIconSet(SmallIconSet("editdelete"));
+        m_delBtn->setIconSet(SmallIconSet("edit-delete"));
         m_delBtn->setTextLabel(i18n("Remove"));
         connect(m_delBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(deleteIdentity()));
 
@@ -100,11 +100,11 @@ namespace Konversation
         m_removeNicknameBtn = new TQPushButton(i18n("Delete"), nicknameGBox);
         m_removeNicknameBtn->setEnabled(false);
         m_upNicknameBtn = new TQToolButton(nicknameGBox);
-        m_upNicknameBtn->setIconSet(SmallIconSet("up"));
+        m_upNicknameBtn->setIconSet(SmallIconSet("go-up"));
         m_upNicknameBtn->setAutoRepeat(true);
         m_upNicknameBtn->setEnabled(false);
         m_downNicknameBtn = new TQToolButton(nicknameGBox);
-        m_downNicknameBtn->setIconSet(SmallIconSet("down"));
+        m_downNicknameBtn->setIconSet(SmallIconSet("go-down"));
         m_downNicknameBtn->setAutoRepeat(true);
         m_downNicknameBtn->setEnabled(false);
 
@@ -583,7 +583,7 @@ namespace Konversation
         }
 
         if(KMessageBox::warningContinueCancel(this, warningTxt, i18n("Delete Identity"),
-            KGuiItem(i18n("Delete"), "editdelete")) == KMessageBox::Continue)
+            KGuiItem(i18n("Delete"), "edit-delete")) == KMessageBox::Continue)
         {
             m_identityCBox->removeItem(current);
             m_identityList.remove(m_currentIdentity);
