@@ -6,7 +6,7 @@
 */
 
 /*
-  ServerListView is derived from KListView and implements custom
+  ServerListView is derived from TDEListView and implements custom
   drag'n'drop behavior needed in ServerListDialog.
 
   Copyright (C) 2006 Eike Hein <hein@kde.org>
@@ -15,15 +15,15 @@
 #ifndef SERVERLISTVIEW_H
 #define SERVERLISTVIEW_H
 
-#include <klistview.h>
+#include <tdelistview.h>
 
 
 class TQDragObject;
 
-class ServerListView : public KListView
+class ServerListView : public TDEListView
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         explicit ServerListView(TQWidget *parent);
